@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-node-view.c,v 1.25 2003/08/22 11:02:08 marco Exp $
+ *  $Id: ephy-node-view.c,v 1.26 2003/08/24 14:49:48 chpe Exp $
  */
 
 #include <gtk/gtktreeselection.h>
@@ -1370,7 +1370,8 @@ ephy_node_view_remove (EphyNodeView *view)
 	 */
 
 	list = ephy_node_view_get_selection (view);
-	g_return_if_fail (list != NULL);
+	if (list == NULL) return;
+
 	node = g_list_first (list)->data;
 	ephy_tree_model_node_iter_from_node (EPHY_TREE_MODEL_NODE (view->priv->nodemodel),
 					     node, &iter);
